Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(43)

Unified Diff: third_party/WebKit/Source/platform/graphics/paint/DisplayItemList.h

Issue 1397583002: Implement the framework for a paint property hierarchy (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Job insecurity: better tests, better comments, better names. Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/paint/DisplayItemList.h
diff --git a/third_party/WebKit/Source/platform/graphics/paint/DisplayItemList.h b/third_party/WebKit/Source/platform/graphics/paint/DisplayItemList.h
index 9082ebd2c9584471e01e57b052734df1c24a861c..482c81ac2d87e24c4596e873db235391d02a72f6 100644
--- a/third_party/WebKit/Source/platform/graphics/paint/DisplayItemList.h
+++ b/third_party/WebKit/Source/platform/graphics/paint/DisplayItemList.h
@@ -78,9 +78,10 @@ public:
// These methods are called during painting.
- // Provide a new set of paint properties to apply to recorded display items,
- // for Slimming Paint v2.
- void updateCurrentPaintProperties(const PaintProperties&);
+ // Provide a new set of paint chunk properties to apply to recorded display
+ // items, for Slimming Paint v2.
+ // TODO(pdr): This should be moved to PaintArtifact.
+ void updateCurrentPaintChunkProperties(const PaintChunkProperties&);
template <typename DisplayItemClass, typename... Args>
void createAndAppend(Args&&... args)

Powered by Google App Engine
This is Rietveld 408576698